Learn R Programming

OwenQ (version 1.0.7)

OwenQ1: First Owen Q-function

Description

Evaluates the first Owen Q-function (integral from \(0\) to \(R\)) for an integer value of the degrees of freedom.

Usage

OwenQ1(nu, t, delta, R, algo = 2)

Value

A vector of numbers between \(0\) and \(1\), the values of the integral from \(0\) to \(R\).

Arguments

nu

integer greater than \(1\), the number of degrees of freedom

t

number, positive or negative, possibly infinite

delta

vector of finite numbers, with the same length as R

R

(upper bound of the integral) vector of finite positive numbers, with the same length as delta

algo

the algorithm, 1 or 2

References

Owen, D. B. (1965). A special case of a bivariate noncentral t-distribution. Biometrika 52, 437-446.

Examples

Run this code
# As R goes to Inf, OwenQ1(nu, t, delta, R) goes to pt(t, nu, delta):
OwenQ1(nu=5, t=3, delta=2, R=100)
pt(q=3, df=5, ncp=2)

Run the code above in your browser using DataLab