powered by
Evaluates the first Owen Q-function (integral from \(0\) to \(R\)) for an integer value of the degrees of freedom.
OwenQ1(nu, t, delta, R, algo = 2)
A vector of numbers between \(0\) and \(1\), the values of the integral from \(0\) to \(R\).
integer greater than \(1\), the number of degrees of freedom
number, positive or negative, possibly infinite
vector of finite numbers, with the same length as R
R
(upper bound of the integral) vector of finite positive numbers, with the same length as delta
delta
the algorithm, 1 or 2
1
2
Owen, D. B. (1965). A special case of a bivariate noncentral t-distribution. Biometrika 52, 437-446.
# As R goes to Inf, OwenQ1(nu, t, delta, R) goes to pt(t, nu, delta): OwenQ1(nu=5, t=3, delta=2, R=100) pt(q=3, df=5, ncp=2)
Run the code above in your browser using DataLab